mascot_render: Render the mascot for a given state and heartbeat tick.

View source: R/mascot.R

mascot_renderR Documentation

Render the mascot for a given state and heartbeat tick.

Description

Render the mascot for a given state and heartbeat tick.

Usage

mascot_render(state, tick = 0L, cosmetics = NULL)

Arguments

state

One of the five mascot states.

tick

Integer tick counter for the heartbeat animation.

cosmetics

Optional wardrobe state list (slot -> equipped id).

Value

Character vector of lines.


texanshootR documentation built on May 30, 2026, 9:11 a.m.