run_log: Browse persisted run history

View source: R/run.R

run_logR Documentation

Browse persisted run history

Description

Returns a data.frame of recent runs with one row per run. The full run record can be loaded via attr(run_log(), "records")[[i]].

Usage

run_log(n = 25L)

Arguments

n

Maximum number of runs to list.

Value

A data.frame with one row per run.


texanshootR documentation built on May 30, 2026, 9:11 a.m.