| vocab | R Documentation |
These exported character vectors define the valid values for the
tags, career_min, trigger_phase, mascot_state_affinity, and
event effects fields used in inst/messages/*.yaml and
inst/events/*.yaml. validate_messages() enforces them.
vocab_tags
vocab_phases
vocab_careers
vocab_mascot_states
vocab_effects
career_levels()
An object of class character of length 39.
An object of class character of length 16.
An object of class character of length 4.
An object of class character of length 9.
An object of class character of length 9.
vocab_tags: Valid tags values. The lower-case fallacy
names from the design contract plus thematic content tags.
vocab_phases: Valid trigger_phase values.
vocab_careers: Valid career_min values.
vocab_mascot_states: Valid mascot_state_affinity values.
vocab_effects: Valid event-effect keys for inst/events/*.yaml.
career_levels(): Career level ordering (low to high).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.